@@ -17,7 +17,7 @@ export default function ToolbarSaveButton(_ref, _ref2) {
 
   return React.createElement(
     ToolbarButton,
-    { tooltip: translator.t("Save project"), onClick: saveProjectToFile },
+    { active: false, tooltip: translator.t("Save project"), onClick: saveProjectToFile },
     React.createElement(IconSave, null)
   );
 }
