@@ -2,11 +2,11 @@ import React, {PropTypes} from 'react';
 import FormLabel from '../../components/style/form-label'
 import FormNumberInput from '../../components/style/form-number-input';
 
-export default function PropertyString({propertyName, value, onUpdate, configs}) {
+export default function PropertyString({value, onUpdate, configs}) {
   return (
     <div style={{marginBottom: "3px"}}>
       <div style={{display: "inline-block", width: "30%"}}>
-        <FormLabel>{propertyName}</FormLabel>
+        <FormLabel>{configs.label}</FormLabel>
       </div>
 
       <div style={{display: "inline-block", width: "70%"}}>
@@ -20,7 +20,6 @@ export default function PropertyString({propertyName, value, onUpdate, configs})
 }
 
 PropertyString.propTypes = {
-  propertyName: PropTypes.string.isRequired,
   value: PropTypes.any.isRequired,
   onUpdate: PropTypes.func.isRequired,
   configs: PropTypes.object.isRequired
